package com.sooka.system.mapper;

import java.util.List;
import com.sooka.system.domain.TUPeoplemarryinfodouble;

/**
 * 国家民政部-婚姻信息（双方）-数据查询接口Mapper接口
 * 
 * @author lei
 * @date 2021-07-14
 */
public interface TUPeoplemarryinfodoubleMapper 
{
    /**
     * 查询国家民政部-婚姻信息（双方）-数据查询接口
     * 
     * @param id 国家民政部-婚姻信息（双方）-数据查询接口ID
     * @return 国家民政部-婚姻信息（双方）-数据查询接口
     */
    public TUPeoplemarryinfodouble selectTUPeoplemarryinfodoubleById(String id);

    /**
     * 查询国家民政部-婚姻信息（双方）-数据查询接口列表
     * 
     * @param tUPeoplemarryinfodouble 国家民政部-婚姻信息（双方）-数据查询接口
     * @return 国家民政部-婚姻信息（双方）-数据查询接口集合
     */
    public List<TUPeoplemarryinfodouble> selectTUPeoplemarryinfodoubleList(TUPeoplemarryinfodouble tUPeoplemarryinfodouble);

    /**
     * 新增国家民政部-婚姻信息（双方）-数据查询接口
     * 
     * @param tUPeoplemarryinfodouble 国家民政部-婚姻信息（双方）-数据查询接口
     * @return 结果
     */
    public int insertTUPeoplemarryinfodouble(TUPeoplemarryinfodouble tUPeoplemarryinfodouble);

    /**
     * 修改国家民政部-婚姻信息（双方）-数据查询接口
     * 
     * @param tUPeoplemarryinfodouble 国家民政部-婚姻信息（双方）-数据查询接口
     * @return 结果
     */
    public int updateTUPeoplemarryinfodouble(TUPeoplemarryinfodouble tUPeoplemarryinfodouble);

    /**
     * 删除国家民政部-婚姻信息（双方）-数据查询接口
     * 
     * @param id 国家民政部-婚姻信息（双方）-数据查询接口ID
     * @return 结果
     */
    public int deleteTUPeoplemarryinfodoubleById(String id);

    /**
     * 批量删除国家民政部-婚姻信息（双方）-数据查询接口
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTUPeoplemarryinfodoubleByIds(String[] ids);
}
